"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AmqpConsumerErrorResolver = void 0;
const node_util_1 = require("node:util");
const node_core_1 = require("@lokalise/node-core");
const zod_1 = require("zod");
const amqpErrors_1 = require("./amqpErrors");
class AmqpConsumerErrorResolver {
    processError(error) {
        if (node_util_1.types.isNativeError(error) && error?.name === 'SyntaxError') {
            return new amqpErrors_1.AmqpMessageInvalidFormat({
                message: error.message,
            });
        }
        if (error instanceof zod_1.ZodError) {
            return new amqpErrors_1.AmqpValidationError({
                message: error.message,
                details: {
                    error: error.issues,
                },
            });
        }
        if ((0, node_core_1.isStandardizedError)(error)) {
            return new node_core_1.InternalError({
                message: error.message,
                errorCode: error.code,
            });
        }
        return new node_core_1.InternalError({
            message: 'Error processing message',
            errorCode: 'INTERNAL_ERROR',
        });
    }
}
exports.AmqpConsumerErrorResolver = AmqpConsumerErrorResolver;
//# sourceMappingURL=AmqpConsumerErrorResolver.js.map